package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjDcfxDzfcMapper;
import com.zjsgfa.project.zjsgfa.domain.SjDcfxDzfc;
import com.zjsgfa.project.zjsgfa.service.ISjDcfxDzfcService;

/**
 * 设计-地层分析—地质分层Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-28
 */
@Service
public class SjDcfxDzfcServiceImpl implements ISjDcfxDzfcService 
{
    @Autowired
    private SjDcfxDzfcMapper sjDcfxDzfcMapper;

    /**
     * 查询设计-地层分析—地质分层
     * 
     * @param id 设计-地层分析—地质分层主键
     * @return 设计-地层分析—地质分层
     */
    @Override
    public SjDcfxDzfc selectSjDcfxDzfcById(Long id)
    {
        return sjDcfxDzfcMapper.selectSjDcfxDzfcById(id);
    }

    /**
     * 查询设计-地层分析—地质分层列表
     * 
     * @param sjDcfxDzfc 设计-地层分析—地质分层
     * @return 设计-地层分析—地质分层
     */
    @Override
    public List<SjDcfxDzfc> selectSjDcfxDzfcList(SjDcfxDzfc sjDcfxDzfc)
    {
        return sjDcfxDzfcMapper.selectSjDcfxDzfcList(sjDcfxDzfc);
    }

    /**
     * 新增设计-地层分析—地质分层
     * 
     * @param sjDcfxDzfc 设计-地层分析—地质分层
     * @return 结果
     */
    @Override
    public int insertSjDcfxDzfc(SjDcfxDzfc sjDcfxDzfc)
    {
        return sjDcfxDzfcMapper.insertSjDcfxDzfc(sjDcfxDzfc);
    }

    /**
     * 修改设计-地层分析—地质分层
     * 
     * @param sjDcfxDzfc 设计-地层分析—地质分层
     * @return 结果
     */
    @Override
    public int updateSjDcfxDzfc(SjDcfxDzfc sjDcfxDzfc)
    {
        return sjDcfxDzfcMapper.updateSjDcfxDzfc(sjDcfxDzfc);
    }

    /**
     * 批量删除设计-地层分析—地质分层
     * 
     * @param ids 需要删除的设计-地层分析—地质分层主键
     * @return 结果
     */
    @Override
    public int deleteSjDcfxDzfcByIds(Long[] ids)
    {
        return sjDcfxDzfcMapper.deleteSjDcfxDzfcByIds(ids);
    }

    /**
     * 删除设计-地层分析—地质分层信息
     * 
     * @param id 设计-地层分析—地质分层主键
     * @return 结果
     */
    @Override
    public int deleteSjDcfxDzfcById(Long id)
    {
        return sjDcfxDzfcMapper.deleteSjDcfxDzfcById(id);
    }
}
